/*globals define, QUnit, window*/
define([
    'jquery',
    'testsuite/qunit',
    'testsuite/qunit-fixture!de_epages/presentation/ui/inputaction-test.html',

    'de_epages/presentation/ui/inputaction',
    '$ready!'
], function ($, Q, fixture) {
    'use strict';

    var inputaction,
        input,
        button,
        value = '7.5';

    QUnit.module("de_epages/presentation/ui/inputaction", {
        setup: function () {
            fixture.init();
            inputaction = $('#inputactionId').presentationUiInputaction();
            input = $('#inputactionId');
            button = $('#qunit-fixture span.ep-inputaction-span');
        },
        teardown: function () {
            fixture.destroy();
        }
    });

    Q.asyncTest('Check HTML structure and the functionality', function () {
        Q.strictEqual(
            button.length,
            1,
            'Reset button was inserted'
        );

        Q.ok(
            button.eq(0).is('visible') === false,
            'Reset button is initially not visible'
        );

        Q.ok(
            button.eq(0).hasClass('fa-reply'),
            'Reset button has the font awesome class "fa-reply"'
        );

        ['paste', 'keyup'].forEach(function (elem) {
            Q.equal(
                $._data(input[0], "events")[elem] !== undefined,
                true,
                'Event "' + elem + '" was registered'
            );
        });

        // insert a value to the input and trigger keyup
        input.val(value);
        input.trigger('keyup');

        window.setTimeout(function () {
            Q.equal(
                button.eq(0).css('visibility'),
                'visible',
                'After inserting a value to the input the reset button is visible'
            );

            // check value in input
            Q.equal(
                input.val(),
                value,
                'Input field contains the value "' + value + '"'
            );
            // trigger click on reset button to reset the input
            button.eq(0).trigger('click');
            // check value in input again
            Q.equal(
                input.val().length,
                0,
                'After clicking the reset button the input field is empty'
            );

            // destroy widget
            input.presentationUiInputaction('destroy');

            Q.strictEqual(
                $('#qunit-fixture span.ep-inputaction-span').length,
                0,
                'Reset button was removed'
            );

            Q.equal(
                $._data(input[0], "events") === undefined,
                true,
                'Events were removed'
            );

            Q.start();
        }, 100);
    });
});
